@@ -116,7 +116,7 @@ check_cd_status(void)
             if (last == CDP_CDROM_UMOUNT) {
                 syslog (LOG_INFO, "Disk detected.  Mounting");
                 snprintf(cmd, sizeof cmd,
-                        "/lib/udev/ltspfs_entry add_disc %s iso9660", device);
+                        "/lib/udev/ltspfs_entry add_disc %s iso9660,udf", device);
                 last = CDP_CDROM_MOUNT;
                 return g_spawn_command_line_sync(cmd, NULL, NULL, NULL, NULL);
             }
